@@ -4,6 +4,7 @@ from pycocotools import mask
 import numpy as np
 import cv2
 import json
+import unittest
 from collections import defaultdict
 import torch
 from torch.utils.data import Dataset
@@ -44,6 +45,8 @@ def parse_arguments():
     parser.add_argument('-imflags', type=int, default=cv2.IMREAD_COLOR, help='cv2.imdecode flags')
     parser.add_argument('-cuda', type=bool, default=True)
 
+    parser.add_argument('--test', '-t', type=json.loads, default=None,help='Array of test parametrs or empty quote for nothing') 
+
     parser.add_argument('-getcoco', action='store_true',help='Get coco dataset') 
     parser.add_argument('-cocourl', type=json.loads, default=None, 
                         help='List of coco dataset URLs to load.  If none, coco 2017 datafiles are loaded from https://cocodataset.org/#download')
@@ -60,6 +63,11 @@ def parse_arguments():
 
 def main(args):
 
+    if args.test  is not None:
+        sys.argv = [sys.argv[0]]
+        sys.argv.extend(args.test)
+        unittest.main()
+
     s3, creds, s3def = Connect(args.credentials)
 
     if args.getcoco:
